@@ -4,7 +4,9 @@ logger = logging.getLogger(__name__)
 
 handler = logging.StreamHandler()
 
-format_string = "%(asctime)s - %(levelname)s - %(filename)s:%(lineno)d - %(funcName)s - %(message)s"
+format_string = (
+    "%(asctime)s - %(levelname)s - %(filename)s:%(lineno)d - %(funcName)s - %(message)s"
+)
 formatter = logging.Formatter(format_string)
 handler.setFormatter(formatter)
 
